Calculate corrected RJC (Rotnitzky-Jewell information criterion) based on GEE with a modified robust variance estimator.
Usage
RJ2.gee(object)
Arguments
object
a fitted model object of class "wgee".
Value
Return the value of the corrected Rotnitzky-Jewell information criterion (RJC).
References
Rotnitzky, A. and Jewell, N.P., 1990. Hypothesis testing of regression parameters in semiparametric generalized linear models for cluster correlated data. Biometrika, pp.485-497.
Wang, M. and Long, Q., 2011. Modified robust variance estimator for generalized estimating equations with improved small-sample performance. Statistics in Medicine, 30(11), pp. 1278-1291.